==> nextcloud-app-richdocuments-1.1.25-3-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/richdocuments/l10n/da.js <==
OC.L10N.register(
    "richdocuments",
    {
    "Saving..." : "Gemmer...",
    "Latest revision" : "Seneste revision",
    "More versions..." : "Flere versioner...",
    "Just now" : "Lige nu",
    "Failed to revert the document to older version" : "Det lykkedes ikke at gendanne dokumentet, til en ældre version",
    "Save" : "Gem",
    "Loading documents..." : "Henter dokumenter...",
    "Edit" : "Redigér",
    "Document" : "Dokument",
    "Spreadsheet" : "Regneark",
    "Presentation" : "Præsentation",
    "Could not create file" : "Kunne ikke oprette fil",
    "New Document.odt" : "Nyt dokument.odt",
    "New Spreadsheet.ods" : "Nyt regneark.ods",
    "New Presentation.odp" : "Ny præsentation.odp",
    "New Document.docx" : "Nyt dokument.docx",
    "New Spreadsheet.xlsx" : "Nyt regneark.xlsx",
    "New Presentation.pptx" : "Nyt præsentation.pptx",
    "Can't create document" : "Kan ikke oprette dokument",
    "Saved" : "Gemt",
    "Saved with error: Collabora Online should use the same protocol as the server installation." : "Gemt med fejl: Collabora Online skal bruge samme protokol som server installationen.",
    "Collabora Online" : "Collabora Online",
    "Collabora Online server" : "Collabora Online server",
    "URL (and port) of the Collabora Online server that provides the editing functionality as a WOPI client." : "URL (og port) i Collabora  Online serveren, der giver redigeringsfunktionalitet som en WOPI klient.",
    "Apply" : "Anvend",
    "Use OOXML by default for new files" : "Brug OOXML for standard for nye filer.",
    "Wrong password. Please retry." : "Forkert kodeord. Prøv igen.",
    "Password" : "Kodeord",
    "OK" : "OK",
    "Guest %s" : "Gæst %s",
    "This link has been expired or is never existed. Please contact the person who shared it with you for details." : "Dette link er uløbet eller har aldrig eksisteret. Kontakt venligst personen der delte linket for yderligere detaljer. "
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-richdocuments-1.12.31-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/richdocuments/l10n/da.js <==
OC.L10N.register(
    "richdocuments",
    {
    "Saving..." : "Gemmer...",
    "Download this revision" : "Hent denne revision",
    "Restore this revision" : "Gendan denne revision",
    "Latest revision" : "Seneste revision",
    "More versions..." : "Flere versioner...",
    "Just now" : "Lige nu",
    "Failed to revert the document to older version" : "Det lykkedes ikke at gendanne dokumentet, til en ældre version",
    "Save" : "Gem",
    "Loading documents..." : "Henter dokumenter...",
    "Edit" : "Redigér",
    "Could not create file" : "Kunne ikke oprette fil",
    "New Document.odt" : "Nyt dokument.odt",
    "New Spreadsheet.ods" : "Nyt regneark.ods",
    "New Presentation.odp" : "Ny præsentation.odp",
    "New Document.docx" : "Nyt dokument.docx",
    "New Spreadsheet.xlsx" : "Nyt regneark.xlsx",
    "New Presentation.pptx" : "Nyt præsentation.pptx",
    "Can't create document" : "Kan ikke oprette dokument",
    "Saved" : "Gemt",
    "Saved with error: Collabora Online should use the same protocol as the server installation." : "Gemt med fejl: Collabora Online skal bruge samme protokol som server installationen.",
    "Collabora Online" : "Collabora Online",
    "Collabora Online server" : "Collabora Online server",
    "URL (and port) of the Collabora Online server that provides the editing functionality as a WOPI client." : "URL (og port) i Collabora  Online serveren, der giver redigeringsfunktionalitet som en WOPI klient.",
    "Apply" : "Anvend",
    "Use OOXML by default for new files" : "Brug OOXML for standard for nye filer.",
    "Wrong password. Please retry." : "Forkert kodeord. Prøv igen.",
    "Password" : "Kodeord",
    "OK" : "OK",
    "Guest %s" : "Gæst %s",
    "This link has been expired or is never existed. Please contact the person who shared it with you for details." : "Dette link er uløbet eller har aldrig eksisteret. Kontakt venligst personen der delte linket for yderligere detaljer. "
},
"nplurals=2; plural=(n != 1);");
